@@ -4,7 +4,7 @@ import numpy as np
 from pykin.planners.planner import Planner
 from pykin.planners.tree import Tree
 from pykin.utils.log_utils import create_logger
-from pykin.utils.kin_utils import ShellColors as sc
+from pykin.utils.kin_utils import ShellColors as sc, logging_time
 from pykin.utils.transform_utils import get_linear_interpoation
 
 logger = create_logger('RRT Star Planner', "debug")
@@ -59,7 +59,9 @@ class RRTStarPlanner(Planner):
 
     def __repr__(self):
         return 'pykin.planners.rrt_star_planner.{}()'.format(type(self).__name__)
-        
+    
+
+    @logging_time
     def get_path_in_joinst_space(self, cur_q, goal_pose, resolution=1):
         """
         Get path in joint space
